@@ -1,7 +1,11 @@
 
+# Update version on PyPi:
+# python3 setup.py sdist
+# twine upload dist/*
+
 __name__ = 'pyplasma'
 __author__ = 'Jean-Luc Déziel'
-__version__ = '0.3.2'
+__version__ = '0.4.1'
 
 from .backend import backend
 from .backend import set_backend
@@ -9,6 +13,7 @@ from .backend import set_backend
 from .simulation import Domain
 from .laser import Laser
 from .material import Material
+from .traps import Trap
 from .observers import *
 
 import scipy.constants as c
